import {Injectable} from '@angular/core';
import {Observable} from "rxjs";
import {HttpClient} from "@angular/common/http";
import {map} from "rxjs/operators";
import {ConfigurationService} from "../env/configuration.service";
import {Flux} from "../model/flux";

@Injectable({
  providedIn: 'root'
})
export class CalibratorsService {

  endPoint: string = '/services/calibrators/';

  constructor(private http: HttpClient, private configService: ConfigurationService) {
  }

  public getCalibrators(): Observable<any> {
    return this.http.get(this.configService.config.url + this.endPoint, {observe: 'response'}).pipe(
      map(response => {
        return response.body;
      }));
  }

  public saveCalibratorFlux(sctId: number, fluxId: number, frequency: number, flux: number, spectralIndex: number, uvmin: number, uvmax: number) {
    let params = new Flux();

    params.frequency = frequency;
    params.flux = flux;
    params.spectralIndex = spectralIndex;
    params.observingDate = null;
    params.uvMin = uvmin;
    params.uvMax = uvmax;
    params.id = fluxId;

    return this.http.post(this.configService.config.url + this.endPoint + sctId + '/flux/' + fluxId, params, {observe: 'response'}).pipe(
      map(response => {
        if (response.status >= 200 && response.status < 300) {
          return params;
        }
      })
    );
  }

}
